import datetime
import typing

import kubernetes.client

class V1ObjectReference:
    api_version: typing.Optional[str]
    field_path: typing.Optional[str]
    kind: typing.Optional[str]
    name: typing.Optional[str]
    namespace: typing.Optional[str]
    resource_version: typing.Optional[str]
    uid: typing.Optional[str]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        field_path: typing.Optional[str] = ...,
        kind: typing.Optional[str] = ...,
        name: typing.Optional[str] = ...,
        namespace: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        uid: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1ObjectReferenceDict: ...

class V1ObjectReferenceDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    fieldPath: typing.Optional[str]
    kind: typing.Optional[str]
    name: typing.Optional[str]
    namespace: typing.Optional[str]
    resourceVersion: typing.Optional[str]
    uid: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1AzureFileVolumeSource:
    read_only: typing.Optional[bool]
    secret_name: str
    share_name: str
    def __init__(
        self,
        *,
        read_only: typing.Optional[bool] = ...,
        secret_name: str,
        share_name: str
    ) -> None: ...
    def to_dict(self) -> V1AzureFileVolumeSourceDict: ...

class V1AzureFileVolumeSourceDict(typing.TypedDict, total=False):
    readOnly: typing.Optional[bool]
    secretName: str
    shareName: str



import datetime
import typing

import kubernetes.client

class V2beta1HorizontalPodAutoscalerSpec:
    max_replicas: int
    metrics: typing.Optional[list[kubernetes.client.V2beta1MetricSpec]]
    min_replicas: typing.Optional[int]
    scale_target_ref: kubernetes.client.V2beta1CrossVersionObjectReference
    def __init__(
        self,
        *,
        max_replicas: int,
        metrics: typing.Optional[list[kubernetes.client.V2beta1MetricSpec]] = ...,
        min_replicas: typing.Optional[int] = ...,
        scale_target_ref: kubernetes.client.V2beta1CrossVersionObjectReference
    ) -> None: ...
    def to_dict(self) -> V2beta1HorizontalPodAutoscalerSpecDict: ...

class V2beta1HorizontalPodAutoscalerSpecDict(typing.TypedDict, total=False):
    maxReplicas: int
    metrics: typing.Optional[list[kubernetes.client.V2beta1MetricSpecDict]]
    minReplicas: typing.Optional[int]
    scaleTargetRef: kubernetes.client.V2beta1CrossVersionObjectReferenceDict



import datetime
import typing

import kubernetes.client

class V1Taint:
    effect: str
    key: str
    time_added: typing.Optional[datetime.datetime]
    value: typing.Optional[str]
    def __init__(
        self,
        *,
        effect: str,
        key: str,
        time_added: typing.Optional[datetime.datetime] = ...,
        value: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1TaintDict: ...

class V1TaintDict(typing.TypedDict, total=False):
    effect: str
    key: str
    timeAdded: typing.Optional[datetime.datetime]
    value: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1StorageClass:
    allow_volume_expansion: typing.Optional[bool]
    allowed_topologies: typing.Optional[list[kubernetes.client.V1TopologySelectorTerm]]
    api_version: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMeta]
    mount_options: typing.Optional[list[str]]
    parameters: typing.Optional[dict[str, str]]
    provisioner: str
    reclaim_policy: typing.Optional[str]
    volume_binding_mode: typing.Optional[str]
    def __init__(
        self,
        *,
        allow_volume_expansion: typing.Optional[bool] = ...,
        allowed_topologies: typing.Optional[
            list[kubernetes.client.V1TopologySelectorTerm]
        ] = ...,
        api_version: typing.Optional[str] = ...,
        kind: typing.Optional[str] = ...,
        metadata: typing.Optional[kubernetes.client.V1ObjectMeta] = ...,
        mount_options: typing.Optional[list[str]] = ...,
        parameters: typing.Optional[dict[str, str]] = ...,
        provisioner: str,
        reclaim_policy: typing.Optional[str] = ...,
        volume_binding_mode: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1StorageClassDict: ...

class V1StorageClassDict(typing.TypedDict, total=False):
    allowVolumeExpansion: typing.Optional[bool]
    allowedTopologies: typing.Optional[
        list[kubernetes.client.V1TopologySelectorTermDict]
    ]
    apiVersion: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMetaDict]
    mountOptions: typing.Optional[list[str]]
    parameters: typing.Optional[dict[str, str]]
    provisioner: str
    reclaimPolicy: typing.Optional[str]
    volumeBindingMode: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1PortworxVolumeSource:
    fs_type: typing.Optional[str]
    read_only: typing.Optional[bool]
    volume_id: str
    def __init__(
        self,
        *,
        fs_type: typing.Optional[str] = ...,
        read_only: typing.Optional[bool] = ...,
        volume_id: str
    ) -> None: ...
    def to_dict(self) -> V1PortworxVolumeSourceDict: ...

class V1PortworxVolumeSourceDict(typing.TypedDict, total=False):
    fsType: typing.Optional[str]
    readOnly: typing.Optional[bool]
    volumeID: str



import datetime
import typing

import kubernetes.client

class V1CustomResourceDefinitionNames:
    categories: typing.Optional[list[str]]
    kind: str
    list_kind: typing.Optional[str]
    plural: str
    short_names: typing.Optional[list[str]]
    singular: typing.Optional[str]
    def __init__(
        self,
        *,
        categories: typing.Optional[list[str]] = ...,
        kind: str,
        list_kind: typing.Optional[str] = ...,
        plural: str,
        short_names: typing.Optional[list[str]] = ...,
        singular: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1CustomResourceDefinitionNamesDict: ...

class V1CustomResourceDefinitionNamesDict(typing.TypedDict, total=False):
    categories: typing.Optional[list[str]]
    kind: str
    listKind: typing.Optional[str]
    plural: str
    shortNames: typing.Optional[list[str]]
    singular: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class ApiregistrationV1beta1ServiceReference:
    name: typing.Optional[str]
    namespace: typing.Optional[str]
    port: typing.Optional[int]
    def __init__(
        self,
        *,
        name: typing.Optional[str] = ...,
        namespace: typing.Optional[str] = ...,
        port: typing.Optional[int] = ...
    ) -> None: ...
    def to_dict(self) -> ApiregistrationV1beta1ServiceReferenceDict: ...

class ApiregistrationV1beta1ServiceReferenceDict(typing.TypedDict, total=False):
    name: typing.Optional[str]
    namespace: typing.Optional[str]
    port: typing.Optional[int]



import datetime
import typing

import kubernetes.client

class V1APIGroupList:
    api_version: typing.Optional[str]
    groups: list[kubernetes.client.V1APIGroup]
    kind: typing.Optional[str]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        groups: list[kubernetes.client.V1APIGroup],
        kind: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1APIGroupListDict: ...

class V1APIGroupListDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    groups: list[kubernetes.client.V1APIGroupDict]
    kind: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1beta1SELinuxStrategyOptions:
    rule: str
    se_linux_options: typing.Optional[kubernetes.client.V1SELinuxOptions]
    def __init__(
        self,
        *,
        rule: str,
        se_linux_options: typing.Optional[kubernetes.client.V1SELinuxOptions] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1SELinuxStrategyOptionsDict: ...

class V1beta1SELinuxStrategyOptionsDict(typing.TypedDict, total=False):
    rule: str
    seLinuxOptions: typing.Optional[kubernetes.client.V1SELinuxOptionsDict]



import datetime
import typing

import kubernetes.client

class V1beta1CSIDriverSpec:
    attach_required: typing.Optional[bool]
    fs_group_policy: typing.Optional[str]
    pod_info_on_mount: typing.Optional[bool]
    requires_republish: typing.Optional[bool]
    storage_capacity: typing.Optional[bool]
    token_requests: typing.Optional[list[kubernetes.client.V1beta1TokenRequest]]
    volume_lifecycle_modes: typing.Optional[list[str]]
    def __init__(
        self,
        *,
        attach_required: typing.Optional[bool] = ...,
        fs_group_policy: typing.Optional[str] = ...,
        pod_info_on_mount: typing.Optional[bool] = ...,
        requires_republish: typing.Optional[bool] = ...,
        storage_capacity: typing.Optional[bool] = ...,
        token_requests: typing.Optional[
            list[kubernetes.client.V1beta1TokenRequest]
        ] = ...,
        volume_lifecycle_modes: typing.Optional[list[str]] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1CSIDriverSpecDict: ...

class V1beta1CSIDriverSpecDict(typing.TypedDict, total=False):
    attachRequired: typing.Optional[bool]
    fsGroupPolicy: typing.Optional[str]
    podInfoOnMount: typing.Optional[bool]
    requiresRepublish: typing.Optional[bool]
    storageCapacity: typing.Optional[bool]
    tokenRequests: typing.Optional[list[kubernetes.client.V1beta1TokenRequestDict]]
    volumeLifecycleModes: typing.Optional[list[str]]



import datetime
import typing

import kubernetes.client

class V1PolicyRule:
    api_groups: typing.Optional[list[str]]
    non_resource_ur_ls: typing.Optional[list[str]]
    resource_names: typing.Optional[list[str]]
    resources: typing.Optional[list[str]]
    verbs: list[str]
    def __init__(
        self,
        *,
        api_groups: typing.Optional[list[str]] = ...,
        non_resource_ur_ls: typing.Optional[list[str]] = ...,
        resource_names: typing.Optional[list[str]] = ...,
        resources: typing.Optional[list[str]] = ...,
        verbs: list[str]
    ) -> None: ...
    def to_dict(self) -> V1PolicyRuleDict: ...

class V1PolicyRuleDict(typing.TypedDict, total=False):
    apiGroups: typing.Optional[list[str]]
    nonResourceURLs: typing.Optional[list[str]]
    resourceNames: typing.Optional[list[str]]
    resources: typing.Optional[list[str]]
    verbs: list[str]



import datetime
import typing

import kubernetes.client

class V1PodReadinessGate:
    condition_type: str
    def __init__(self, *, condition_type: str) -> None: ...
    def to_dict(self) -> V1PodReadinessGateDict: ...

class V1PodReadinessGateDict(typing.TypedDict, total=False):
    conditionType: str



import datetime
import typing

import kubernetes.client

class V1EventSource:
    component: typing.Optional[str]
    host: typing.Optional[str]
    def __init__(
        self, *, component: typing.Optional[str] = ..., host: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1EventSourceDict: ...

class V1EventSourceDict(typing.TypedDict, total=False):
    component: typing.Optional[str]
    host: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1StatusDetails:
    causes: typing.Optional[list[kubernetes.client.V1StatusCause]]
    group: typing.Optional[str]
    kind: typing.Optional[str]
    name: typing.Optional[str]
    retry_after_seconds: typing.Optional[int]
    uid: typing.Optional[str]
    def __init__(
        self,
        *,
        causes: typing.Optional[list[kubernetes.client.V1StatusCause]] = ...,
        group: typing.Optional[str] = ...,
        kind: typing.Optional[str] = ...,
        name: typing.Optional[str] = ...,
        retry_after_seconds: typing.Optional[int] = ...,
        uid: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1StatusDetailsDict: ...

class V1StatusDetailsDict(typing.TypedDict, total=False):
    causes: typing.Optional[list[kubernetes.client.V1StatusCauseDict]]
    group: typing.Optional[str]
    kind: typing.Optional[str]
    name: typing.Optional[str]
    retryAfterSeconds: typing.Optional[int]
    uid: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1OwnerReference:
    api_version: str
    block_owner_deletion: typing.Optional[bool]
    controller: typing.Optional[bool]
    kind: str
    name: str
    uid: str
    def __init__(
        self,
        *,
        api_version: str,
        block_owner_deletion: typing.Optional[bool] = ...,
        controller: typing.Optional[bool] = ...,
        kind: str,
        name: str,
        uid: str
    ) -> None: ...
    def to_dict(self) -> V1OwnerReferenceDict: ...

class V1OwnerReferenceDict(typing.TypedDict, total=False):
    apiVersion: str
    blockOwnerDeletion: typing.Optional[bool]
    controller: typing.Optional[bool]
    kind: str
    name: str
    uid: str



import datetime
import typing

import kubernetes.client

class V1WindowsSecurityContextOptions:
    gmsa_credential_spec: typing.Optional[str]
    gmsa_credential_spec_name: typing.Optional[str]
    run_as_user_name: typing.Optional[str]
    def __init__(
        self,
        *,
        gmsa_credential_spec: typing.Optional[str] = ...,
        gmsa_credential_spec_name: typing.Optional[str] = ...,
        run_as_user_name: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1WindowsSecurityContextOptionsDict: ...

class V1WindowsSecurityContextOptionsDict(typing.TypedDict, total=False):
    gmsaCredentialSpec: typing.Optional[str]
    gmsaCredentialSpecName: typing.Optional[str]
    runAsUserName: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1Affinity:
    node_affinity: typing.Optional[kubernetes.client.V1NodeAffinity]
    pod_affinity: typing.Optional[kubernetes.client.V1PodAffinity]
    pod_anti_affinity: typing.Optional[kubernetes.client.V1PodAntiAffinity]
    def __init__(
        self,
        *,
        node_affinity: typing.Optional[kubernetes.client.V1NodeAffinity] = ...,
        pod_affinity: typing.Optional[kubernetes.client.V1PodAffinity] = ...,
        pod_anti_affinity: typing.Optional[kubernetes.client.V1PodAntiAffinity] = ...
    ) -> None: ...
    def to_dict(self) -> V1AffinityDict: ...

class V1AffinityDict(typing.TypedDict, total=False):
    nodeAffinity: typing.Optional[kubernetes.client.V1NodeAffinityDict]
    podAffinity: typing.Optional[kubernetes.client.V1PodAffinityDict]
    podAntiAffinity: typing.Optional[kubernetes.client.V1PodAntiAffinityDict]



import datetime
import typing

import kubernetes.client

class V1Endpoints:
    api_version: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMeta]
    subsets: typing.Optional[list[kubernetes.client.V1EndpointSubset]]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        kind: typing.Optional[str] = ...,
        metadata: typing.Optional[kubernetes.client.V1ObjectMeta] = ...,
        subsets: typing.Optional[list[kubernetes.client.V1EndpointSubset]] = ...
    ) -> None: ...
    def to_dict(self) -> V1EndpointsDict: ...

class V1EndpointsDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMetaDict]
    subsets: typing.Optional[list[kubernetes.client.V1EndpointSubsetDict]]



import datetime
import typing

import kubernetes.client

class CoreV1EventSeries:
    count: typing.Optional[int]
    last_observed_time: typing.Optional[datetime.datetime]
    def __init__(
        self,
        *,
        count: typing.Optional[int] = ...,
        last_observed_time: typing.Optional[datetime.datetime] = ...
    ) -> None: ...
    def to_dict(self) -> CoreV1EventSeriesDict: ...

class CoreV1EventSeriesDict(typing.TypedDict, total=False):
    count: typing.Optional[int]
    lastObservedTime: typing.Optional[datetime.datetime]



import datetime
import typing

import kubernetes.client

class V1GCEPersistentDiskVolumeSource:
    fs_type: typing.Optional[str]
    partition: typing.Optional[int]
    pd_name: str
    read_only: typing.Optional[bool]
    def __init__(
        self,
        *,
        fs_type: typing.Optional[str] = ...,
        partition: typing.Optional[int] = ...,
        pd_name: str,
        read_only: typing.Optional[bool] = ...
    ) -> None: ...
    def to_dict(self) -> V1GCEPersistentDiskVolumeSourceDict: ...

class V1GCEPersistentDiskVolumeSourceDict(typing.TypedDict, total=False):
    fsType: typing.Optional[str]
    partition: typing.Optional[int]
    pdName: str
    readOnly: typing.Optional[bool]



import datetime
import typing

import kubernetes.client

class V1IngressSpec:
    default_backend: typing.Optional[kubernetes.client.V1IngressBackend]
    ingress_class_name: typing.Optional[str]
    rules: typing.Optional[list[kubernetes.client.V1IngressRule]]
    tls: typing.Optional[list[kubernetes.client.V1IngressTLS]]
    def __init__(
        self,
        *,
        default_backend: typing.Optional[kubernetes.client.V1IngressBackend] = ...,
        ingress_class_name: typing.Optional[str] = ...,
        rules: typing.Optional[list[kubernetes.client.V1IngressRule]] = ...,
        tls: typing.Optional[list[kubernetes.client.V1IngressTLS]] = ...
    ) -> None: ...
    def to_dict(self) -> V1IngressSpecDict: ...

class V1IngressSpecDict(typing.TypedDict, total=False):
    defaultBackend: typing.Optional[kubernetes.client.V1IngressBackendDict]
    ingressClassName: typing.Optional[str]
    rules: typing.Optional[list[kubernetes.client.V1IngressRuleDict]]
    tls: typing.Optional[list[kubernetes.client.V1IngressTLSDict]]



import datetime
import typing

import kubernetes.client

class V1AttachedVolume:
    device_path: str
    name: str
    def __init__(self, *, device_path: str, name: str) -> None: ...
    def to_dict(self) -> V1AttachedVolumeDict: ...

class V1AttachedVolumeDict(typing.TypedDict, total=False):
    devicePath: str
    name: str



import datetime
import typing

import kubernetes.client

class V1alpha1PriorityLevelConfigurationStatus:
    conditions: typing.Optional[
        list[kubernetes.client.V1alpha1PriorityLevelConfigurationCondition]
    ]
    def __init__(
        self,
        *,
        conditions: typing.Optional[
            list[kubernetes.client.V1alpha1PriorityLevelConfigurationCondition]
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1alpha1PriorityLevelConfigurationStatusDict: ...

class V1alpha1PriorityLevelConfigurationStatusDict(typing.TypedDict, total=False):
    conditions: typing.Optional[
        list[kubernetes.client.V1alpha1PriorityLevelConfigurationConditionDict]
    ]



import datetime
import typing

import kubernetes.client

class V1Lifecycle:
    post_start: typing.Optional[kubernetes.client.V1Handler]
    pre_stop: typing.Optional[kubernetes.client.V1Handler]
    def __init__(
        self,
        *,
        post_start: typing.Optional[kubernetes.client.V1Handler] = ...,
        pre_stop: typing.Optional[kubernetes.client.V1Handler] = ...
    ) -> None: ...
    def to_dict(self) -> V1LifecycleDict: ...

class V1LifecycleDict(typing.TypedDict, total=False):
    postStart: typing.Optional[kubernetes.client.V1HandlerDict]
    preStop: typing.Optional[kubernetes.client.V1HandlerDict]



import datetime
import typing

import kubernetes.client

class V1beta1PriorityClass:
    api_version: typing.Optional[str]
    description: typing.Optional[str]
    global_default: typing.Optional[bool]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMeta]
    preemption_policy: typing.Optional[str]
    value: int
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        description: typing.Optional[str] = ...,
        global_default: typing.Optional[bool] = ...,
        kind: typing.Optional[str] = ...,
        metadata: typing.Optional[kubernetes.client.V1ObjectMeta] = ...,
        preemption_policy: typing.Optional[str] = ...,
        value: int
    ) -> None: ...
    def to_dict(self) -> V1beta1PriorityClassDict: ...

class V1beta1PriorityClassDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    description: typing.Optional[str]
    globalDefault: typing.Optional[bool]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMetaDict]
    preemptionPolicy: typing.Optional[str]
    value: int



import datetime
import typing

import kubernetes.client

class V1Sysctl:
    name: str
    value: str
    def __init__(self, *, name: str, value: str) -> None: ...
    def to_dict(self) -> V1SysctlDict: ...

class V1SysctlDict(typing.TypedDict, total=False):
    name: str
    value: str



import datetime
import typing

import kubernetes.client

class V1HTTPIngressPath:
    backend: kubernetes.client.V1IngressBackend
    path: typing.Optional[str]
    path_type: typing.Optional[str]
    def __init__(
        self,
        *,
        backend: kubernetes.client.V1IngressBackend,
        path: typing.Optional[str] = ...,
        path_type: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1HTTPIngressPathDict: ...

class V1HTTPIngressPathDict(typing.TypedDict, total=False):
    backend: kubernetes.client.V1IngressBackendDict
    path: typing.Optional[str]
    pathType: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1beta1CustomResourceValidation:
    open_apiv3_schema: typing.Optional[kubernetes.client.V1beta1JSONSchemaProps]
    def __init__(
        self,
        *,
        open_apiv3_schema: typing.Optional[
            kubernetes.client.V1beta1JSONSchemaProps
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1CustomResourceValidationDict: ...

class V1beta1CustomResourceValidationDict(typing.TypedDict, total=False):
    openAPIV3Schema: typing.Optional[kubernetes.client.V1beta1JSONSchemaPropsDict]



import typing

import kubernetes.client

class StorageV1beta1Api:
    def __init__(
        self, api_client: typing.Optional[kubernetes.client.ApiClient] = ...
    ) -> None: ...
    def get_api_resources(self) -> kubernetes.client.V1APIResourceList: ...
    def list_csi_driver(
        self,
        *,
        pretty: typing.Optional[str] = ...,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1beta1CSIDriverList: ...
    def create_csi_driver(
        self,
        body: kubernetes.client.V1beta1CSIDriver,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1beta1CSIDriver: ...
    def delete_collection_csi_driver(
        self,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        _continue: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...
    ) -> kubernetes.client.V1Status: ...
    def read_csi_driver(
        self,
        name: str,
        *,
        pretty: typing.Optional[str] = ...,
        exact: typing.Optional[bool] = ...,
        export: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1beta1CSIDriver: ...
    def replace_csi_driver(
        self,
        name: str,
        body: kubernetes.client.V1beta1CSIDriver,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1beta1CSIDriver: ...
    def delete_csi_driver(
        self,
        name: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        dry_run: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...
    ) -> kubernetes.client.V1beta1CSIDriver: ...
    def patch_csi_driver(
        self,
        name: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1beta1CSIDriver: ...
    def list_csi_node(
        self,
        *,
        pretty: typing.Optional[str] = ...,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1beta1CSINodeList: ...
    def create_csi_node(
        self,
        body: kubernetes.client.V1beta1CSINode,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1beta1CSINode: ...
    def delete_collection_csi_node(
        self,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        _continue: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...
    ) -> kubernetes.client.V1Status: ...
    def read_csi_node(
        self,
        name: str,
        *,
        pretty: typing.Optional[str] = ...,
        exact: typing.Optional[bool] = ...,
        export: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1beta1CSINode: ...
    def replace_csi_node(
        self,
        name: str,
        body: kubernetes.client.V1beta1CSINode,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1beta1CSINode: ...
    def delete_csi_node(
        self,
        name: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        dry_run: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...
    ) -> kubernetes.client.V1beta1CSINode: ...
    def patch_csi_node(
        self,
        name: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1beta1CSINode: ...
    def list_storage_class(
        self,
        *,
        pretty: typing.Optional[str] = ...,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1beta1StorageClassList: ...
    def create_storage_class(
        self,
        body: kubernetes.client.V1beta1StorageClass,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1beta1StorageClass: ...
    def delete_collection_storage_class(
        self,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        _continue: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...
    ) -> kubernetes.client.V1Status: ...
    def read_storage_class(
        self,
        name: str,
        *,
        pretty: typing.Optional[str] = ...,
        exact: typing.Optional[bool] = ...,
        export: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1beta1StorageClass: ...
    def replace_storage_class(
        self,
        name: str,
        body: kubernetes.client.V1beta1StorageClass,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1beta1StorageClass: ...
    def delete_storage_class(
        self,
        name: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        dry_run: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...
    ) -> kubernetes.client.V1beta1StorageClass: ...
    def patch_storage_class(
        self,
        name: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1beta1StorageClass: ...
    def list_volume_attachment(
        self,
        *,
        pretty: typing.Optional[str] = ...,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1beta1VolumeAttachmentList: ...
    def create_volume_attachment(
        self,
        body: kubernetes.client.V1beta1VolumeAttachment,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1beta1VolumeAttachment: ...
    def delete_collection_volume_attachment(
        self,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        _continue: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...
    ) -> kubernetes.client.V1Status: ...
    def read_volume_attachment(
        self,
        name: str,
        *,
        pretty: typing.Optional[str] = ...,
        exact: typing.Optional[bool] = ...,
        export: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1beta1VolumeAttachment: ...
    def replace_volume_attachment(
        self,
        name: str,
        body: kubernetes.client.V1beta1VolumeAttachment,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1beta1VolumeAttachment: ...
    def delete_volume_attachment(
        self,
        name: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        dry_run: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...
    ) -> kubernetes.client.V1beta1VolumeAttachment: ...
    def patch_volume_attachment(
        self,
        name: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1beta1VolumeAttachment: ...



import datetime
import typing

import kubernetes.client

class V1alpha1Scheduling:
    node_selector: typing.Optional[dict[str, str]]
    tolerations: typing.Optional[list[kubernetes.client.V1Toleration]]
    def __init__(
        self,
        *,
        node_selector: typing.Optional[dict[str, str]] = ...,
        tolerations: typing.Optional[list[kubernetes.client.V1Toleration]] = ...
    ) -> None: ...
    def to_dict(self) -> V1alpha1SchedulingDict: ...

class V1alpha1SchedulingDict(typing.TypedDict, total=False):
    nodeSelector: typing.Optional[dict[str, str]]
    tolerations: typing.Optional[list[kubernetes.client.V1TolerationDict]]



import datetime
import typing

import kubernetes.client

class V2beta2PodsMetricStatus:
    current: kubernetes.client.V2beta2MetricValueStatus
    metric: kubernetes.client.V2beta2MetricIdentifier
    def __init__(
        self,
        *,
        current: kubernetes.client.V2beta2MetricValueStatus,
        metric: kubernetes.client.V2beta2MetricIdentifier
    ) -> None: ...
    def to_dict(self) -> V2beta2PodsMetricStatusDict: ...

class V2beta2PodsMetricStatusDict(typing.TypedDict, total=False):
    current: kubernetes.client.V2beta2MetricValueStatusDict
    metric: kubernetes.client.V2beta2MetricIdentifierDict



import datetime
import typing

import kubernetes.client

class V2beta2HorizontalPodAutoscaler:
    api_version: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMeta]
    spec: typing.Optional[kubernetes.client.V2beta2HorizontalPodAutoscalerSpec]
    status: typing.Optional[kubernetes.client.V2beta2HorizontalPodAutoscalerStatus]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        kind: typing.Optional[str] = ...,
        metadata: typing.Optional[kubernetes.client.V1ObjectMeta] = ...,
        spec: typing.Optional[
            kubernetes.client.V2beta2HorizontalPodAutoscalerSpec
        ] = ...,
        status: typing.Optional[
            kubernetes.client.V2beta2HorizontalPodAutoscalerStatus
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V2beta2HorizontalPodAutoscalerDict: ...

class V2beta2HorizontalPodAutoscalerDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMetaDict]
    spec: typing.Optional[kubernetes.client.V2beta2HorizontalPodAutoscalerSpecDict]
    status: typing.Optional[kubernetes.client.V2beta2HorizontalPodAutoscalerStatusDict]



import datetime
import typing

import kubernetes.client

class V1StorageOSPersistentVolumeSource:
    fs_type: typing.Optional[str]
    read_only: typing.Optional[bool]
    secret_ref: typing.Optional[kubernetes.client.V1ObjectReference]
    volume_name: typing.Optional[str]
    volume_namespace: typing.Optional[str]
    def __init__(
        self,
        *,
        fs_type: typing.Optional[str] = ...,
        read_only: typing.Optional[bool] = ...,
        secret_ref: typing.Optional[kubernetes.client.V1ObjectReference] = ...,
        volume_name: typing.Optional[str] = ...,
        volume_namespace: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1StorageOSPersistentVolumeSourceDict: ...

class V1StorageOSPersistentVolumeSourceDict(typing.TypedDict, total=False):
    fsType: typing.Optional[str]
    readOnly: typing.Optional[bool]
    secretRef: typing.Optional[kubernetes.client.V1ObjectReferenceDict]
    volumeName: typing.Optional[str]
    volumeNamespace: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1Condition:
    last_transition_time: datetime.datetime
    message: str
    observed_generation: typing.Optional[int]
    reason: str
    status: str
    type: str
    def __init__(
        self,
        *,
        last_transition_time: datetime.datetime,
        message: str,
        observed_generation: typing.Optional[int] = ...,
        reason: str,
        status: str,
        type: str
    ) -> None: ...
    def to_dict(self) -> V1ConditionDict: ...

class V1ConditionDict(typing.TypedDict, total=False):
    lastTransitionTime: datetime.datetime
    message: str
    observedGeneration: typing.Optional[int]
    reason: str
    status: str
    type: str



import datetime
import typing

import kubernetes.client

class V1ContainerStateWaiting:
    message: typing.Optional[str]
    reason: typing.Optional[str]
    def __init__(
        self, *, message: typing.Optional[str] = ..., reason: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1ContainerStateWaitingDict: ...

class V1ContainerStateWaitingDict(typing.TypedDict, total=False):
    message: typing.Optional[str]
    reason: typing.Optional[str]



import typing

import kubernetes.client

class AdmissionregistrationApi:
    def __init__(
        self, api_client: typing.Optional[kubernetes.client.ApiClient] = ...
    ) -> None: ...
    def get_api_group(self) -> kubernetes.client.V1APIGroup: ...



import datetime
import typing

import kubernetes.client

class V1ExternalDocumentation:
    description: typing.Optional[str]
    url: typing.Optional[str]
    def __init__(
        self,
        *,
        description: typing.Optional[str] = ...,
        url: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1ExternalDocumentationDict: ...

class V1ExternalDocumentationDict(typing.TypedDict, total=False):
    description: typing.Optional[str]
    url: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class ExtensionsV1beta1HTTPIngressRuleValue:
    paths: list[kubernetes.client.ExtensionsV1beta1HTTPIngressPath]
    def __init__(
        self, *, paths: list[kubernetes.client.ExtensionsV1beta1HTTPIngressPath]
    ) -> None: ...
    def to_dict(self) -> ExtensionsV1beta1HTTPIngressRuleValueDict: ...

class ExtensionsV1beta1HTTPIngressRuleValueDict(typing.TypedDict, total=False):
    paths: list[kubernetes.client.ExtensionsV1beta1HTTPIngressPathDict]



import datetime
import typing

import kubernetes.client

class V1beta1EndpointSlice:
    address_type: str
    api_version: typing.Optional[str]
    endpoints: list[kubernetes.client.V1beta1Endpoint]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMeta]
    ports: typing.Optional[list[kubernetes.client.V1beta1EndpointPort]]
    def __init__(
        self,
        *,
        address_type: str,
        api_version: typing.Optional[str] = ...,
        endpoints: list[kubernetes.client.V1beta1Endpoint],
        kind: typing.Optional[str] = ...,
        metadata: typing.Optional[kubernetes.client.V1ObjectMeta] = ...,
        ports: typing.Optional[list[kubernetes.client.V1beta1EndpointPort]] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1EndpointSliceDict: ...

class V1beta1EndpointSliceDict(typing.TypedDict, total=False):
    addressType: str
    apiVersion: typing.Optional[str]
    endpoints: list[kubernetes.client.V1beta1EndpointDict]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMetaDict]
    ports: typing.Optional[list[kubernetes.client.V1beta1EndpointPortDict]]



import datetime
import typing

import kubernetes.client

class V1TokenReviewStatus:
    audiences: typing.Optional[list[str]]
    authenticated: typing.Optional[bool]
    error: typing.Optional[str]
    user: typing.Optional[kubernetes.client.V1UserInfo]
    def __init__(
        self,
        *,
        audiences: typing.Optional[list[str]] = ...,
        authenticated: typing.Optional[bool] = ...,
        error: typing.Optional[str] = ...,
        user: typing.Optional[kubernetes.client.V1UserInfo] = ...
    ) -> None: ...
    def to_dict(self) -> V1TokenReviewStatusDict: ...

class V1TokenReviewStatusDict(typing.TypedDict, total=False):
    audiences: typing.Optional[list[str]]
    authenticated: typing.Optional[bool]
    error: typing.Optional[str]
    user: typing.Optional[kubernetes.client.V1UserInfoDict]



import datetime
import typing

import kubernetes.client

class V1PodDNSConfig:
    nameservers: typing.Optional[list[str]]
    options: typing.Optional[list[kubernetes.client.V1PodDNSConfigOption]]
    searches: typing.Optional[list[str]]
    def __init__(
        self,
        *,
        nameservers: typing.Optional[list[str]] = ...,
        options: typing.Optional[list[kubernetes.client.V1PodDNSConfigOption]] = ...,
        searches: typing.Optional[list[str]] = ...
    ) -> None: ...
    def to_dict(self) -> V1PodDNSConfigDict: ...

class V1PodDNSConfigDict(typing.TypedDict, total=False):
    nameservers: typing.Optional[list[str]]
    options: typing.Optional[list[kubernetes.client.V1PodDNSConfigOptionDict]]
    searches: typing.Optional[list[str]]



import datetime
import typing

import kubernetes.client

class V1CustomResourceColumnDefinition:
    description: typing.Optional[str]
    format: typing.Optional[str]
    json_path: str
    name: str
    priority: typing.Optional[int]
    type: str
    def __init__(
        self,
        *,
        description: typing.Optional[str] = ...,
        format: typing.Optional[str] = ...,
        json_path: str,
        name: str,
        priority: typing.Optional[int] = ...,
        type: str
    ) -> None: ...
    def to_dict(self) -> V1CustomResourceColumnDefinitionDict: ...

class V1CustomResourceColumnDefinitionDict(typing.TypedDict, total=False):
    description: typing.Optional[str]
    format: typing.Optional[str]
    jsonPath: str
    name: str
    priority: typing.Optional[int]
    type: str



import typing

import kubernetes.client

class LogsApi:
    def __init__(
        self, api_client: typing.Optional[kubernetes.client.ApiClient] = ...
    ) -> None: ...
    def log_file_list_handler(self) -> None: ...
    def log_file_handler(self, logpath: str) -> None: ...



import datetime
import typing

import kubernetes.client

class V1alpha1LimitResponse:
    queuing: typing.Optional[kubernetes.client.V1alpha1QueuingConfiguration]
    type: str
    def __init__(
        self,
        *,
        queuing: typing.Optional[kubernetes.client.V1alpha1QueuingConfiguration] = ...,
        type: str
    ) -> None: ...
    def to_dict(self) -> V1alpha1LimitResponseDict: ...

class V1alpha1LimitResponseDict(typing.TypedDict, total=False):
    queuing: typing.Optional[kubernetes.client.V1alpha1QueuingConfigurationDict]
    type: str



import datetime
import typing

import kubernetes.client

class V1QuobyteVolumeSource:
    group: typing.Optional[str]
    read_only: typing.Optional[bool]
    registry: str
    tenant: typing.Optional[str]
    user: typing.Optional[str]
    volume: str
    def __init__(
        self,
        *,
        group: typing.Optional[str] = ...,
        read_only: typing.Optional[bool] = ...,
        registry: str,
        tenant: typing.Optional[str] = ...,
        user: typing.Optional[str] = ...,
        volume: str
    ) -> None: ...
    def to_dict(self) -> V1QuobyteVolumeSourceDict: ...

class V1QuobyteVolumeSourceDict(typing.TypedDict, total=False):
    group: typing.Optional[str]
    readOnly: typing.Optional[bool]
    registry: str
    tenant: typing.Optional[str]
    user: typing.Optional[str]
    volume: str



import datetime
import typing

import kubernetes.client

class V1EnvFromSource:
    config_map_ref: typing.Optional[kubernetes.client.V1ConfigMapEnvSource]
    prefix: typing.Optional[str]
    secret_ref: typing.Optional[kubernetes.client.V1SecretEnvSource]
    def __init__(
        self,
        *,
        config_map_ref: typing.Optional[kubernetes.client.V1ConfigMapEnvSource] = ...,
        prefix: typing.Optional[str] = ...,
        secret_ref: typing.Optional[kubernetes.client.V1SecretEnvSource] = ...
    ) -> None: ...
    def to_dict(self) -> V1EnvFromSourceDict: ...

class V1EnvFromSourceDict(typing.TypedDict, total=False):
    configMapRef: typing.Optional[kubernetes.client.V1ConfigMapEnvSourceDict]
    prefix: typing.Optional[str]
    secretRef: typing.Optional[kubernetes.client.V1SecretEnvSourceDict]



import datetime
import typing

import kubernetes.client

class V1ScaleIOPersistentVolumeSource:
    fs_type: typing.Optional[str]
    gateway: str
    protection_domain: typing.Optional[str]
    read_only: typing.Optional[bool]
    secret_ref: kubernetes.client.V1SecretReference
    ssl_enabled: typing.Optional[bool]
    storage_mode: typing.Optional[str]
    storage_pool: typing.Optional[str]
    system: str
    volume_name: typing.Optional[str]
    def __init__(
        self,
        *,
        fs_type: typing.Optional[str] = ...,
        gateway: str,
        protection_domain: typing.Optional[str] = ...,
        read_only: typing.Optional[bool] = ...,
        secret_ref: kubernetes.client.V1SecretReference,
        ssl_enabled: typing.Optional[bool] = ...,
        storage_mode: typing.Optional[str] = ...,
        storage_pool: typing.Optional[str] = ...,
        system: str,
        volume_name: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1ScaleIOPersistentVolumeSourceDict: ...

class V1ScaleIOPersistentVolumeSourceDict(typing.TypedDict, total=False):
    fsType: typing.Optional[str]
    gateway: str
    protectionDomain: typing.Optional[str]
    readOnly: typing.Optional[bool]
    secretRef: kubernetes.client.V1SecretReferenceDict
    sslEnabled: typing.Optional[bool]
    storageMode: typing.Optional[str]
    storagePool: typing.Optional[str]
    system: str
    volumeName: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1alpha1FlowSchemaSpec:
    distinguisher_method: typing.Optional[
        kubernetes.client.V1alpha1FlowDistinguisherMethod
    ]
    matching_precedence: typing.Optional[int]
    priority_level_configuration: kubernetes.client.V1alpha1PriorityLevelConfigurationReference
    rules: typing.Optional[list[kubernetes.client.V1alpha1PolicyRulesWithSubjects]]
    def __init__(
        self,
        *,
        distinguisher_method: typing.Optional[
            kubernetes.client.V1alpha1FlowDistinguisherMethod
        ] = ...,
        matching_precedence: typing.Optional[int] = ...,
        priority_level_configuration: kubernetes.client.V1alpha1PriorityLevelConfigurationReference,
        rules: typing.Optional[
            list[kubernetes.client.V1alpha1PolicyRulesWithSubjects]
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1alpha1FlowSchemaSpecDict: ...

class V1alpha1FlowSchemaSpecDict(typing.TypedDict, total=False):
    distinguisherMethod: typing.Optional[
        kubernetes.client.V1alpha1FlowDistinguisherMethodDict
    ]
    matchingPrecedence: typing.Optional[int]
    priorityLevelConfiguration: kubernetes.client.V1alpha1PriorityLevelConfigurationReferenceDict
    rules: typing.Optional[list[kubernetes.client.V1alpha1PolicyRulesWithSubjectsDict]]



import datetime
import typing

import kubernetes.client

class V1SecretKeySelector:
    key: str
    name: typing.Optional[str]
    optional: typing.Optional[bool]
    def __init__(
        self,
        *,
        key: str,
        name: typing.Optional[str] = ...,
        optional: typing.Optional[bool] = ...
    ) -> None: ...
    def to_dict(self) -> V1SecretKeySelectorDict: ...

class V1SecretKeySelectorDict(typing.TypedDict, total=False):
    key: str
    name: typing.Optional[str]
    optional: typing.Optional[bool]



import datetime
import typing

import kubernetes.client

class EventsV1Event:
    action: typing.Optional[str]
    api_version: typing.Optional[str]
    deprecated_count: typing.Optional[int]
    deprecated_first_timestamp: typing.Optional[datetime.datetime]
    deprecated_last_timestamp: typing.Optional[datetime.datetime]
    deprecated_source: typing.Optional[kubernetes.client.V1EventSource]
    event_time: datetime.datetime
    kind: typing.Optional[str]
    metadata: kubernetes.client.V1ObjectMeta
    note: typing.Optional[str]
    reason: typing.Optional[str]
    regarding: typing.Optional[kubernetes.client.V1ObjectReference]
    related: typing.Optional[kubernetes.client.V1ObjectReference]
    reporting_controller: typing.Optional[str]
    reporting_instance: typing.Optional[str]
    series: typing.Optional[kubernetes.client.EventsV1EventSeries]
    type: typing.Optional[str]
    def __init__(
        self,
        *,
        action: typing.Optional[str] = ...,
        api_version: typing.Optional[str] = ...,
        deprecated_count: typing.Optional[int] = ...,
        deprecated_first_timestamp: typing.Optional[datetime.datetime] = ...,
        deprecated_last_timestamp: typing.Optional[datetime.datetime] = ...,
        deprecated_source: typing.Optional[kubernetes.client.V1EventSource] = ...,
        event_time: datetime.datetime,
        kind: typing.Optional[str] = ...,
        metadata: kubernetes.client.V1ObjectMeta,
        note: typing.Optional[str] = ...,
        reason: typing.Optional[str] = ...,
        regarding: typing.Optional[kubernetes.client.V1ObjectReference] = ...,
        related: typing.Optional[kubernetes.client.V1ObjectReference] = ...,
        reporting_controller: typing.Optional[str] = ...,
        reporting_instance: typing.Optional[str] = ...,
        series: typing.Optional[kubernetes.client.EventsV1EventSeries] = ...,
        type: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> EventsV1EventDict: ...

class EventsV1EventDict(typing.TypedDict, total=False):
    action: typing.Optional[str]
    apiVersion: typing.Optional[str]
    deprecatedCount: typing.Optional[int]
    deprecatedFirstTimestamp: typing.Optional[datetime.datetime]
    deprecatedLastTimestamp: typing.Optional[datetime.datetime]
    deprecatedSource: typing.Optional[kubernetes.client.V1EventSourceDict]
    eventTime: datetime.datetime
    kind: typing.Optional[str]
    metadata: kubernetes.client.V1ObjectMetaDict
    note: typing.Optional[str]
    reason: typing.Optional[str]
    regarding: typing.Optional[kubernetes.client.V1ObjectReferenceDict]
    related: typing.Optional[kubernetes.client.V1ObjectReferenceDict]
    reportingController: typing.Optional[str]
    reportingInstance: typing.Optional[str]
    series: typing.Optional[kubernetes.client.EventsV1EventSeriesDict]
    type: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1SubjectAccessReviewStatus:
    allowed: bool
    denied: typing.Optional[bool]
    evaluation_error: typing.Optional[str]
    reason: typing.Optional[str]
    def __init__(
        self,
        *,
        allowed: bool,
        denied: typing.Optional[bool] = ...,
        evaluation_error: typing.Optional[str] = ...,
        reason: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1SubjectAccessReviewStatusDict: ...

class V1SubjectAccessReviewStatusDict(typing.TypedDict, total=False):
    allowed: bool
    denied: typing.Optional[bool]
    evaluationError: typing.Optional[str]
    reason: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1SecretEnvSource:
    name: typing.Optional[str]
    optional: typing.Optional[bool]
    def __init__(
        self, *, name: typing.Optional[str] = ..., optional: typing.Optional[bool] = ...
    ) -> None: ...
    def to_dict(self) -> V1SecretEnvSourceDict: ...

class V1SecretEnvSourceDict(typing.TypedDict, total=False):
    name: typing.Optional[str]
    optional: typing.Optional[bool]



import datetime
import typing

import kubernetes.client

class V1beta1NonResourcePolicyRule:
    non_resource_ur_ls: list[str]
    verbs: list[str]
    def __init__(self, *, non_resource_ur_ls: list[str], verbs: list[str]) -> None: ...
    def to_dict(self) -> V1beta1NonResourcePolicyRuleDict: ...

class V1beta1NonResourcePolicyRuleDict(typing.TypedDict, total=False):
    nonResourceURLs: list[str]
    verbs: list[str]



import datetime
import typing

import kubernetes.client

class V1PersistentVolumeClaimTemplate:
    metadata: typing.Optional[kubernetes.client.V1ObjectMeta]
    spec: kubernetes.client.V1PersistentVolumeClaimSpec
    def __init__(
        self,
        *,
        metadata: typing.Optional[kubernetes.client.V1ObjectMeta] = ...,
        spec: kubernetes.client.V1PersistentVolumeClaimSpec
    ) -> None: ...
    def to_dict(self) -> V1PersistentVolumeClaimTemplateDict: ...

class V1PersistentVolumeClaimTemplateDict(typing.TypedDict, total=False):
    metadata: typing.Optional[kubernetes.client.V1ObjectMetaDict]
    spec: kubernetes.client.V1PersistentVolumeClaimSpecDict



import datetime
import typing

import kubernetes.client

class V1ObjectFieldSelector:
    api_version: typing.Optional[str]
    field_path: str
    def __init__(
        self, *, api_version: typing.Optional[str] = ..., field_path: str
    ) -> None: ...
    def to_dict(self) -> V1ObjectFieldSelectorDict: ...

class V1ObjectFieldSelectorDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    fieldPath: str



import datetime
import typing

import kubernetes.client

class V1VolumeMount:
    mount_path: str
    mount_propagation: typing.Optional[str]
    name: str
    read_only: typing.Optional[bool]
    sub_path: typing.Optional[str]
    sub_path_expr: typing.Optional[str]
    def __init__(
        self,
        *,
        mount_path: str,
        mount_propagation: typing.Optional[str] = ...,
        name: str,
        read_only: typing.Optional[bool] = ...,
        sub_path: typing.Optional[str] = ...,
        sub_path_expr: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1VolumeMountDict: ...

class V1VolumeMountDict(typing.TypedDict, total=False):
    mountPath: str
    mountPropagation: typing.Optional[str]
    name: str
    readOnly: typing.Optional[bool]
    subPath: typing.Optional[str]
    subPathExpr: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1ContainerStateRunning:
    started_at: typing.Optional[datetime.datetime]
    def __init__(
        self, *, started_at: typing.Optional[datetime.datetime] = ...
    ) -> None: ...
    def to_dict(self) -> V1ContainerStateRunningDict: ...

class V1ContainerStateRunningDict(typing.TypedDict, total=False):
    startedAt: typing.Optional[datetime.datetime]



import datetime
import typing

import kubernetes.client

class V2beta1ExternalMetricSource:
    metric_name: str
    metric_selector: typing.Optional[kubernetes.client.V1LabelSelector]
    target_average_value: typing.Optional[str]
    target_value: typing.Optional[str]
    def __init__(
        self,
        *,
        metric_name: str,
        metric_selector: typing.Optional[kubernetes.client.V1LabelSelector] = ...,
        target_average_value: typing.Optional[str] = ...,
        target_value: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V2beta1ExternalMetricSourceDict: ...

class V2beta1ExternalMetricSourceDict(typing.TypedDict, total=False):
    metricName: str
    metricSelector: typing.Optional[kubernetes.client.V1LabelSelectorDict]
    targetAverageValue: typing.Optional[str]
    targetValue: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1beta1CustomResourceDefinitionSpec:
    additional_printer_columns: typing.Optional[
        list[kubernetes.client.V1beta1CustomResourceColumnDefinition]
    ]
    conversion: typing.Optional[kubernetes.client.V1beta1CustomResourceConversion]
    group: str
    names: kubernetes.client.V1beta1CustomResourceDefinitionNames
    preserve_unknown_fields: typing.Optional[bool]
    scope: str
    subresources: typing.Optional[kubernetes.client.V1beta1CustomResourceSubresources]
    validation: typing.Optional[kubernetes.client.V1beta1CustomResourceValidation]
    version: typing.Optional[str]
    versions: typing.Optional[
        list[kubernetes.client.V1beta1CustomResourceDefinitionVersion]
    ]
    def __init__(
        self,
        *,
        additional_printer_columns: typing.Optional[
            list[kubernetes.client.V1beta1CustomResourceColumnDefinition]
        ] = ...,
        conversion: typing.Optional[
            kubernetes.client.V1beta1CustomResourceConversion
        ] = ...,
        group: str,
        names: kubernetes.client.V1beta1CustomResourceDefinitionNames,
        preserve_unknown_fields: typing.Optional[bool] = ...,
        scope: str,
        subresources: typing.Optional[
            kubernetes.client.V1beta1CustomResourceSubresources
        ] = ...,
        validation: typing.Optional[
            kubernetes.client.V1beta1CustomResourceValidation
        ] = ...,
        version: typing.Optional[str] = ...,
        versions: typing.Optional[
            list[kubernetes.client.V1beta1CustomResourceDefinitionVersion]
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1CustomResourceDefinitionSpecDict: ...

class V1beta1CustomResourceDefinitionSpecDict(typing.TypedDict, total=False):
    additionalPrinterColumns: typing.Optional[
        list[kubernetes.client.V1beta1CustomResourceColumnDefinitionDict]
    ]
    conversion: typing.Optional[kubernetes.client.V1beta1CustomResourceConversionDict]
    group: str
    names: kubernetes.client.V1beta1CustomResourceDefinitionNamesDict
    preserveUnknownFields: typing.Optional[bool]
    scope: str
    subresources: typing.Optional[
        kubernetes.client.V1beta1CustomResourceSubresourcesDict
    ]
    validation: typing.Optional[kubernetes.client.V1beta1CustomResourceValidationDict]
    version: typing.Optional[str]
    versions: typing.Optional[
        list[kubernetes.client.V1beta1CustomResourceDefinitionVersionDict]
    ]



import datetime
import typing

import kubernetes.client

class V1SecurityContext:
    allow_privilege_escalation: typing.Optional[bool]
    capabilities: typing.Optional[kubernetes.client.V1Capabilities]
    privileged: typing.Optional[bool]
    proc_mount: typing.Optional[str]
    read_only_root_filesystem: typing.Optional[bool]
    run_as_group: typing.Optional[int]
    run_as_non_root: typing.Optional[bool]
    run_as_user: typing.Optional[int]
    se_linux_options: typing.Optional[kubernetes.client.V1SELinuxOptions]
    seccomp_profile: typing.Optional[kubernetes.client.V1SeccompProfile]
    windows_options: typing.Optional[kubernetes.client.V1WindowsSecurityContextOptions]
    def __init__(
        self,
        *,
        allow_privilege_escalation: typing.Optional[bool] = ...,
        capabilities: typing.Optional[kubernetes.client.V1Capabilities] = ...,
        privileged: typing.Optional[bool] = ...,
        proc_mount: typing.Optional[str] = ...,
        read_only_root_filesystem: typing.Optional[bool] = ...,
        run_as_group: typing.Optional[int] = ...,
        run_as_non_root: typing.Optional[bool] = ...,
        run_as_user: typing.Optional[int] = ...,
        se_linux_options: typing.Optional[kubernetes.client.V1SELinuxOptions] = ...,
        seccomp_profile: typing.Optional[kubernetes.client.V1SeccompProfile] = ...,
        windows_options: typing.Optional[
            kubernetes.client.V1WindowsSecurityContextOptions
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1SecurityContextDict: ...

class V1SecurityContextDict(typing.TypedDict, total=False):
    allowPrivilegeEscalation: typing.Optional[bool]
    capabilities: typing.Optional[kubernetes.client.V1CapabilitiesDict]
    privileged: typing.Optional[bool]
    procMount: typing.Optional[str]
    readOnlyRootFilesystem: typing.Optional[bool]
    runAsGroup: typing.Optional[int]
    runAsNonRoot: typing.Optional[bool]
    runAsUser: typing.Optional[int]
    seLinuxOptions: typing.Optional[kubernetes.client.V1SELinuxOptionsDict]
    seccompProfile: typing.Optional[kubernetes.client.V1SeccompProfileDict]
    windowsOptions: typing.Optional[
        kubernetes.client.V1WindowsSecurityContextOptionsDict
    ]



import datetime
import typing

import kubernetes.client

class V1alpha1VolumeAttachmentStatus:
    attach_error: typing.Optional[kubernetes.client.V1alpha1VolumeError]
    attached: bool
    attachment_metadata: typing.Optional[dict[str, str]]
    detach_error: typing.Optional[kubernetes.client.V1alpha1VolumeError]
    def __init__(
        self,
        *,
        attach_error: typing.Optional[kubernetes.client.V1alpha1VolumeError] = ...,
        attached: bool,
        attachment_metadata: typing.Optional[dict[str, str]] = ...,
        detach_error: typing.Optional[kubernetes.client.V1alpha1VolumeError] = ...
    ) -> None: ...
    def to_dict(self) -> V1alpha1VolumeAttachmentStatusDict: ...

class V1alpha1VolumeAttachmentStatusDict(typing.TypedDict, total=False):
    attachError: typing.Optional[kubernetes.client.V1alpha1VolumeErrorDict]
    attached: bool
    attachmentMetadata: typing.Optional[dict[str, str]]
    detachError: typing.Optional[kubernetes.client.V1alpha1VolumeErrorDict]



import datetime
import typing

import kubernetes.client

class NetworkingV1beta1IngressBackend:
    resource: typing.Optional[kubernetes.client.V1TypedLocalObjectReference]
    service_name: typing.Optional[str]
    service_port: typing.Optional[typing.Any]
    def __init__(
        self,
        *,
        resource: typing.Optional[kubernetes.client.V1TypedLocalObjectReference] = ...,
        service_name: typing.Optional[str] = ...,
        service_port: typing.Optional[typing.Any] = ...
    ) -> None: ...
    def to_dict(self) -> NetworkingV1beta1IngressBackendDict: ...

class NetworkingV1beta1IngressBackendDict(typing.TypedDict, total=False):
    resource: typing.Optional[kubernetes.client.V1TypedLocalObjectReferenceDict]
    serviceName: typing.Optional[str]
    servicePort: typing.Optional[typing.Any]



import datetime
import typing

import kubernetes.client

class V1DaemonSet:
    api_version: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMeta]
    spec: typing.Optional[kubernetes.client.V1DaemonSetSpec]
    status: typing.Optional[kubernetes.client.V1DaemonSetStatus]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        kind: typing.Optional[str] = ...,
        metadata: typing.Optional[kubernetes.client.V1ObjectMeta] = ...,
        spec: typing.Optional[kubernetes.client.V1DaemonSetSpec] = ...,
        status: typing.Optional[kubernetes.client.V1DaemonSetStatus] = ...
    ) -> None: ...
    def to_dict(self) -> V1DaemonSetDict: ...

class V1DaemonSetDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMetaDict]
    spec: typing.Optional[kubernetes.client.V1DaemonSetSpecDict]
    status: typing.Optional[kubernetes.client.V1DaemonSetStatusDict]



import datetime
import typing

import kubernetes.client

class V2beta2ResourceMetricSource:
    name: str
    target: kubernetes.client.V2beta2MetricTarget
    def __init__(
        self, *, name: str, target: kubernetes.client.V2beta2MetricTarget
    ) -> None: ...
    def to_dict(self) -> V2beta2ResourceMetricSourceDict: ...

class V2beta2ResourceMetricSourceDict(typing.TypedDict, total=False):
    name: str
    target: kubernetes.client.V2beta2MetricTargetDict



import datetime
import typing

import kubernetes.client

class V1beta1EventSeries:
    count: int
    last_observed_time: datetime.datetime
    def __init__(
        self, *, count: int, last_observed_time: datetime.datetime
    ) -> None: ...
    def to_dict(self) -> V1beta1EventSeriesDict: ...

class V1beta1EventSeriesDict(typing.TypedDict, total=False):
    count: int
    lastObservedTime: datetime.datetime



import datetime
import typing

import kubernetes.client

class V1ServiceAccount:
    api_version: typing.Optional[str]
    automount_service_account_token: typing.Optional[bool]
    image_pull_secrets: typing.Optional[list[kubernetes.client.V1LocalObjectReference]]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMeta]
    secrets: typing.Optional[list[kubernetes.client.V1ObjectReference]]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        automount_service_account_token: typing.Optional[bool] = ...,
        image_pull_secrets: typing.Optional[
            list[kubernetes.client.V1LocalObjectReference]
        ] = ...,
        kind: typing.Optional[str] = ...,
        metadata: typing.Optional[kubernetes.client.V1ObjectMeta] = ...,
        secrets: typing.Optional[list[kubernetes.client.V1ObjectReference]] = ...
    ) -> None: ...
    def to_dict(self) -> V1ServiceAccountDict: ...

class V1ServiceAccountDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    automountServiceAccountToken: typing.Optional[bool]
    imagePullSecrets: typing.Optional[
        list[kubernetes.client.V1LocalObjectReferenceDict]
    ]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMetaDict]
    secrets: typing.Optional[list[kubernetes.client.V1ObjectReferenceDict]]



import datetime
import typing

import kubernetes.client

class V1IngressTLS:
    hosts: typing.Optional[list[str]]
    secret_name: typing.Optional[str]
    def __init__(
        self,
        *,
        hosts: typing.Optional[list[str]] = ...,
        secret_name: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1IngressTLSDict: ...

class V1IngressTLSDict(typing.TypedDict, total=False):
    hosts: typing.Optional[list[str]]
    secretName: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1Toleration:
    effect: typing.Optional[str]
    key: typing.Optional[str]
    operator: typing.Optional[str]
    toleration_seconds: typing.Optional[int]
    value: typing.Optional[str]
    def __init__(
        self,
        *,
        effect: typing.Optional[str] = ...,
        key: typing.Optional[str] = ...,
        operator: typing.Optional[str] = ...,
        toleration_seconds: typing.Optional[int] = ...,
        value: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1TolerationDict: ...

class V1TolerationDict(typing.TypedDict, total=False):
    effect: typing.Optional[str]
    key: typing.Optional[str]
    operator: typing.Optional[str]
    tolerationSeconds: typing.Optional[int]
    value: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1beta1PodDisruptionBudgetStatus:
    current_healthy: int
    desired_healthy: int
    disrupted_pods: typing.Optional[dict[str, datetime.datetime]]
    disruptions_allowed: int
    expected_pods: int
    observed_generation: typing.Optional[int]
    def __init__(
        self,
        *,
        current_healthy: int,
        desired_healthy: int,
        disrupted_pods: typing.Optional[dict[str, datetime.datetime]] = ...,
        disruptions_allowed: int,
        expected_pods: int,
        observed_generation: typing.Optional[int] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1PodDisruptionBudgetStatusDict: ...

class V1beta1PodDisruptionBudgetStatusDict(typing.TypedDict, total=False):
    currentHealthy: int
    desiredHealthy: int
    disruptedPods: typing.Optional[dict[str, datetime.datetime]]
    disruptionsAllowed: int
    expectedPods: int
    observedGeneration: typing.Optional[int]



import datetime
import typing

import kubernetes.client

class V1GroupVersionForDiscovery:
    group_version: str
    version: str
    def __init__(self, *, group_version: str, version: str) -> None: ...
    def to_dict(self) -> V1GroupVersionForDiscoveryDict: ...

class V1GroupVersionForDiscoveryDict(typing.TypedDict, total=False):
    groupVersion: str
    version: str



import datetime
import typing

import kubernetes.client

class V1ServiceAccountTokenProjection:
    audience: typing.Optional[str]
    expiration_seconds: typing.Optional[int]
    path: str
    def __init__(
        self,
        *,
        audience: typing.Optional[str] = ...,
        expiration_seconds: typing.Optional[int] = ...,
        path: str
    ) -> None: ...
    def to_dict(self) -> V1ServiceAccountTokenProjectionDict: ...

class V1ServiceAccountTokenProjectionDict(typing.TypedDict, total=False):
    audience: typing.Optional[str]
    expirationSeconds: typing.Optional[int]
    path: str



import datetime
import typing

import kubernetes.client

class V1beta1RuntimeClass:
    api_version: typing.Optional[str]
    handler: str
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMeta]
    overhead: typing.Optional[kubernetes.client.V1beta1Overhead]
    scheduling: typing.Optional[kubernetes.client.V1beta1Scheduling]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        handler: str,
        kind: typing.Optional[str] = ...,
        metadata: typing.Optional[kubernetes.client.V1ObjectMeta] = ...,
        overhead: typing.Optional[kubernetes.client.V1beta1Overhead] = ...,
        scheduling: typing.Optional[kubernetes.client.V1beta1Scheduling] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1RuntimeClassDict: ...

class V1beta1RuntimeClassDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    handler: str
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMetaDict]
    overhead: typing.Optional[kubernetes.client.V1beta1OverheadDict]
    scheduling: typing.Optional[kubernetes.client.V1beta1SchedulingDict]



import datetime
import typing

import kubernetes.client

class V2beta1ObjectMetricSource:
    average_value: typing.Optional[str]
    metric_name: str
    selector: typing.Optional[kubernetes.client.V1LabelSelector]
    target: kubernetes.client.V2beta1CrossVersionObjectReference
    target_value: str
    def __init__(
        self,
        *,
        average_value: typing.Optional[str] = ...,
        metric_name: str,
        selector: typing.Optional[kubernetes.client.V1LabelSelector] = ...,
        target: kubernetes.client.V2beta1CrossVersionObjectReference,
        target_value: str
    ) -> None: ...
    def to_dict(self) -> V2beta1ObjectMetricSourceDict: ...

class V2beta1ObjectMetricSourceDict(typing.TypedDict, total=False):
    averageValue: typing.Optional[str]
    metricName: str
    selector: typing.Optional[kubernetes.client.V1LabelSelectorDict]
    target: kubernetes.client.V2beta1CrossVersionObjectReferenceDict
    targetValue: str



from kubernetes.config.config_exception import ConfigException
from kubernetes.config.incluster_config import load_incluster_config
from kubernetes.config.kube_config import (KUBE_CONFIG_DEFAULT_LOCATION,
                                           list_kube_config_contexts,
                                           load_kube_config,
                                           load_kube_config_from_dict,
                                           new_client_from_config)



import datetime
import typing

import kubernetes.client

class V1ContainerStateTerminated:
    container_id: typing.Optional[str]
    exit_code: int
    finished_at: typing.Optional[datetime.datetime]
    message: typing.Optional[str]
    reason: typing.Optional[str]
    signal: typing.Optional[int]
    started_at: typing.Optional[datetime.datetime]
    def __init__(
        self,
        *,
        container_id: typing.Optional[str] = ...,
        exit_code: int,
        finished_at: typing.Optional[datetime.datetime] = ...,
        message: typing.Optional[str] = ...,
        reason: typing.Optional[str] = ...,
        signal: typing.Optional[int] = ...,
        started_at: typing.Optional[datetime.datetime] = ...
    ) -> None: ...
    def to_dict(self) -> V1ContainerStateTerminatedDict: ...

class V1ContainerStateTerminatedDict(typing.TypedDict, total=False):
    containerID: typing.Optional[str]
    exitCode: int
    finishedAt: typing.Optional[datetime.datetime]
    message: typing.Optional[str]
    reason: typing.Optional[str]
    signal: typing.Optional[int]
    startedAt: typing.Optional[datetime.datetime]



import datetime
import typing

import kubernetes.client

class V1beta1Endpoint:
    addresses: list[str]
    conditions: typing.Optional[kubernetes.client.V1beta1EndpointConditions]
    hostname: typing.Optional[str]
    node_name: typing.Optional[str]
    target_ref: typing.Optional[kubernetes.client.V1ObjectReference]
    topology: typing.Optional[dict[str, str]]
    def __init__(
        self,
        *,
        addresses: list[str],
        conditions: typing.Optional[kubernetes.client.V1beta1EndpointConditions] = ...,
        hostname: typing.Optional[str] = ...,
        node_name: typing.Optional[str] = ...,
        target_ref: typing.Optional[kubernetes.client.V1ObjectReference] = ...,
        topology: typing.Optional[dict[str, str]] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1EndpointDict: ...

class V1beta1EndpointDict(typing.TypedDict, total=False):
    addresses: list[str]
    conditions: typing.Optional[kubernetes.client.V1beta1EndpointConditionsDict]
    hostname: typing.Optional[str]
    nodeName: typing.Optional[str]
    targetRef: typing.Optional[kubernetes.client.V1ObjectReferenceDict]
    topology: typing.Optional[dict[str, str]]



import datetime
import typing

import kubernetes.client

class V1HostPathVolumeSource:
    path: str
    type: typing.Optional[str]
    def __init__(self, *, path: str, type: typing.Optional[str] = ...) -> None: ...
    def to_dict(self) -> V1HostPathVolumeSourceDict: ...

class V1HostPathVolumeSourceDict(typing.TypedDict, total=False):
    path: str
    type: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1UserInfo:
    extra: typing.Optional[dict[str, list[str]]]
    groups: typing.Optional[list[str]]
    uid: typing.Optional[str]
    username: typing.Optional[str]
    def __init__(
        self,
        *,
        extra: typing.Optional[dict[str, list[str]]] = ...,
        groups: typing.Optional[list[str]] = ...,
        uid: typing.Optional[str] = ...,
        username: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1UserInfoDict: ...

class V1UserInfoDict(typing.TypedDict, total=False):
    extra: typing.Optional[dict[str, list[str]]]
    groups: typing.Optional[list[str]]
    uid: typing.Optional[str]
    username: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1AzureDiskVolumeSource:
    caching_mode: typing.Optional[str]
    disk_name: str
    disk_uri: str
    fs_type: typing.Optional[str]
    kind: typing.Optional[str]
    read_only: typing.Optional[bool]
    def __init__(
        self,
        *,
        caching_mode: typing.Optional[str] = ...,
        disk_name: str,
        disk_uri: str,
        fs_type: typing.Optional[str] = ...,
        kind: typing.Optional[str] = ...,
        read_only: typing.Optional[bool] = ...
    ) -> None: ...
    def to_dict(self) -> V1AzureDiskVolumeSourceDict: ...

class V1AzureDiskVolumeSourceDict(typing.TypedDict, total=False):
    cachingMode: typing.Optional[str]
    diskName: str
    diskURI: str
    fsType: typing.Optional[str]
    kind: typing.Optional[str]
    readOnly: typing.Optional[bool]



import datetime
import typing

import kubernetes.client

class V1ContainerImage:
    names: list[str]
    size_bytes: typing.Optional[int]
    def __init__(
        self, *, names: list[str], size_bytes: typing.Optional[int] = ...
    ) -> None: ...
    def to_dict(self) -> V1ContainerImageDict: ...

class V1ContainerImageDict(typing.TypedDict, total=False):
    names: list[str]
    sizeBytes: typing.Optional[int]



import datetime
import typing

import kubernetes.client

class V1CephFSPersistentVolumeSource:
    monitors: list[str]
    path: typing.Optional[str]
    read_only: typing.Optional[bool]
    secret_file: typing.Optional[str]
    secret_ref: typing.Optional[kubernetes.client.V1SecretReference]
    user: typing.Optional[str]
    def __init__(
        self,
        *,
        monitors: list[str],
        path: typing.Optional[str] = ...,
        read_only: typing.Optional[bool] = ...,
        secret_file: typing.Optional[str] = ...,
        secret_ref: typing.Optional[kubernetes.client.V1SecretReference] = ...,
        user: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1CephFSPersistentVolumeSourceDict: ...

class V1CephFSPersistentVolumeSourceDict(typing.TypedDict, total=False):
    monitors: list[str]
    path: typing.Optional[str]
    readOnly: typing.Optional[bool]
    secretFile: typing.Optional[str]
    secretRef: typing.Optional[kubernetes.client.V1SecretReferenceDict]
    user: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1beta1PodDisruptionBudgetSpec:
    max_unavailable: typing.Optional[typing.Any]
    min_available: typing.Optional[typing.Any]
    selector: typing.Optional[kubernetes.client.V1LabelSelector]
    def __init__(
        self,
        *,
        max_unavailable: typing.Optional[typing.Any] = ...,
        min_available: typing.Optional[typing.Any] = ...,
        selector: typing.Optional[kubernetes.client.V1LabelSelector] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1PodDisruptionBudgetSpecDict: ...

class V1beta1PodDisruptionBudgetSpecDict(typing.TypedDict, total=False):
    maxUnavailable: typing.Optional[typing.Any]
    minAvailable: typing.Optional[typing.Any]
    selector: typing.Optional[kubernetes.client.V1LabelSelectorDict]



import datetime
import typing

import kubernetes.client

class V1NodeConfigStatus:
    active: typing.Optional[kubernetes.client.V1NodeConfigSource]
    assigned: typing.Optional[kubernetes.client.V1NodeConfigSource]
    error: typing.Optional[str]
    last_known_good: typing.Optional[kubernetes.client.V1NodeConfigSource]
    def __init__(
        self,
        *,
        active: typing.Optional[kubernetes.client.V1NodeConfigSource] = ...,
        assigned: typing.Optional[kubernetes.client.V1NodeConfigSource] = ...,
        error: typing.Optional[str] = ...,
        last_known_good: typing.Optional[kubernetes.client.V1NodeConfigSource] = ...
    ) -> None: ...
    def to_dict(self) -> V1NodeConfigStatusDict: ...

class V1NodeConfigStatusDict(typing.TypedDict, total=False):
    active: typing.Optional[kubernetes.client.V1NodeConfigSourceDict]
    assigned: typing.Optional[kubernetes.client.V1NodeConfigSourceDict]
    error: typing.Optional[str]
    lastKnownGood: typing.Optional[kubernetes.client.V1NodeConfigSourceDict]
